@@ -1,6 +1,3 @@
-# coding=utf-8
-from __future__ import unicode_literals
-
 from .. import Provider as AddressProvider
 
 
@@ -305,12 +302,14 @@ class Provider(AddressProvider):
         'パレス', 'ハイツ', 'コーポ', 'アーバン', 'クレスト', 'パーク', 'シティ', 'シャルム', 'コート',
     )
 
-    def prefecture(self):
+    def administrative_unit(self):
         """
         :example '東京都'
         """
         return self.random_element(self.prefectures)
 
+    prefecture = administrative_unit
+
     def city(self):
         """
         :example '台東区'
